
/**********************************************************************************************/
/*Tool Inventory System Tables.sql*/
/**********************************************************************************************/
if not exists (select * from dbo.sysobjects where id = object_id(N'[PERSON]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
CREATE TABLE [PERSON]
(
	[PersonId] [int] IDENTITY(1, 1) NOT NULL PRIMARY KEY,
	[PersonName] [varchar](100) NOT NULL UNIQUE,
	[PersonTag] [varchar](100) NOT NULL UNIQUE,
	[EMail] [varchar](100) NOT NULL UNIQUE,
	[Password] [varchar](255) NOT NULL,
) 
GO


if not exists (select * from dbo.sysobjects where id = object_id(N'[TOOL]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
CREATE TABLE [TOOL]
(
	[ToolId] [int] IDENTITY(1, 1) NOT NULL PRIMARY KEY,
	[ToolName] [varchar](100) NOT NULL UNIQUE,
	[ToolTag] [varchar](100) NOT NULL UNIQUE,
	[ToolDescription] [varchar](1000) NULL,
	[ToolInUse] [int] NOT NULL,
	[PersonId] [int]  NULL FOREIGN KEY REFERENCES [PERSON] ([PersonId]),
	[RentDate] [datetime] NULL,
) 
GO


if not exists (select * from dbo.sysobjects where id = object_id(N'[GROUP]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
CREATE TABLE [GROUP]
(
	[GroupId] [int] IDENTITY(1, 1) NOT NULL PRIMARY KEY,
	[GroupName] [varchar](100) NOT NULL UNIQUE,
) 
GO


if not exists (select * from dbo.sysobjects where id = object_id(N'[TOOL_GROUP]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
CREATE TABLE [TOOL_GROUP]
(
	[ToolGroupId] [int] IDENTITY(1, 1) NOT NULL PRIMARY KEY,
	[ToolId] [int]  NULL FOREIGN KEY REFERENCES [TOOL] ([ToolId]),
	[GroupId] [int]  NULL FOREIGN KEY REFERENCES [GROUP] ([GroupId]),
) 
GO


if not exists (select * from dbo.sysobjects where id = object_id(N'[SUBGROUP]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
CREATE TABLE [SUBGROUP]
(
	[SubGroupId] [int] IDENTITY(1, 1) NOT NULL PRIMARY KEY,
	[SubGroupName] [varchar](100) NOT NULL UNIQUE,
) 
GO


if not exists (select * from dbo.sysobjects where id = object_id(N'[TOOL_DATA]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
CREATE TABLE [TOOL_DATA]
(
	[ToolDataId] [int] IDENTITY(1, 1) NOT NULL PRIMARY KEY,
	[ToolId] [int]  NOT NULL FOREIGN KEY REFERENCES [TOOL] ([ToolId]),
	[ToolNumber] [varchar](100) NULL,
	[Vendor] [varchar](100) NULL,
	[Model] [varchar](100) NULL,
	[PurchaseDate] [datetime] NULL,
	[CalibrationDate] [datetime] NULL,
	[Price] [float] NULL,
	[Owner] [varchar](100) NULL,
) 
GO


if not exists (select * from dbo.sysobjects where id = object_id(N'[TOOL_RENT]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
CREATE TABLE [TOOL_RENT_HISTORY]
(
	[RentId] [int] IDENTITY(1, 1) NOT NULL PRIMARY KEY,
	[ToolId] [int] NOT NULL FOREIGN KEY REFERENCES [TOOL] ([ToolId]),
	[PersonId] [int] NOT NULL FOREIGN KEY REFERENCES [PERSON] ([PersonId]),
	[RentDate] [datetime] NOT NULL,
	[ReturnDate] [datetime] NOT NULL,
) 
GO
	
/**********************************************************************************************/
/*BorrowTool.sql*/
/**********************************************************************************************/
IF EXISTS (SELECT name 
	   FROM   sysobjects 
	   WHERE  name = 'BorrowTool' 
	   AND 	  type = 'P')
	DROP PROCEDURE BorrowTool
GO

CREATE PROCEDURE BorrowTool
@PersonTag varchar(100),
@ToolTag varchar(100)
AS

DECLARE
@PersonId int

SELECT @PersonId = PersonId FROM PERSON WHERE PersonTag = @PersonTag


UPDATE TOOL SET
ToolInUse = 1,
PersonId = @PersonId,
RentDate = getdate()
WHERE ToolTag = @ToolTag

GO
	
/**********************************************************************************************/
/*BorrowToolById.sql*/
/**********************************************************************************************/
IF EXISTS (SELECT name 
	   FROM   sysobjects 
	   WHERE  name = 'BorrowToolById' 
	   AND 	  type = 'P')
	DROP PROCEDURE BorrowToolById
GO

CREATE PROCEDURE BorrowToolById
@PersonId int,
@ToolId int
AS


UPDATE TOOL SET
ToolInUse = 1,
PersonId = @PersonId,
RentDate = getdate()
WHERE ToolId = @ToolId

GO
	
/**********************************************************************************************/
/*DeletePerson.sql*/
/**********************************************************************************************/
IF EXISTS (SELECT name 
	   FROM   sysobjects 
	   WHERE  name = 'DeletePerson' 
	   AND 	  type = 'P')
	DROP PROCEDURE DeletePerson
GO

CREATE PROCEDURE DeletePerson
@PersonId int
AS

delete from Person where PersonId = @PersonId

GO
	
/**********************************************************************************************/
/*DeleteTool.sql*/
/**********************************************************************************************/
IF EXISTS (SELECT name 
	   FROM   sysobjects 
	   WHERE  name = 'DeleteTool' 
	   AND 	  type = 'P')
	DROP PROCEDURE DeleteTool
GO

CREATE PROCEDURE DeleteTool
@ToolId int
AS

delete from TOOL where ToolId = @ToolId

GO
	
/**********************************************************************************************/
/*NewPerson.sql*/
/**********************************************************************************************/
IF EXISTS (SELECT name 
	   FROM   sysobjects 
	   WHERE  name = 'NewPerson' 
	   AND 	  type = 'P')
	DROP PROCEDURE NewPerson
GO

CREATE PROCEDURE NewPerson
@PersonName varchar(100),
@PersonTag varchar(100),
@EMail varchar(100),
@Password varchar(100)

AS

if not exists (select * from PERSON where PersonName = @PersonName)
	INSERT INTO PERSON (PersonName, PersonTag, EMail, [Password]) 
	VALUES (@PersonName, @PersonTag, @EMail, @Password)

GO
	
/**********************************************************************************************/
/*NewTool.sql*/
/**********************************************************************************************/
IF EXISTS (SELECT name 
	   FROM   sysobjects 
	   WHERE  name = 'NewTool' 
	   AND 	  type = 'P')
	DROP PROCEDURE NewTool
GO

CREATE PROCEDURE NewTool
@ToolName varchar(100),
@ToolTag varchar(100),
@ToolDescription varchar(1000)

AS

if not exists (select * from TOOL where ToolName = @ToolName)
	INSERT INTO TOOL (ToolName, ToolTag, ToolDescription, ToolInUse) 
	VALUES (@ToolName, @ToolTag, @ToolDescription, 0)

GO
	
/**********************************************************************************************/
/*ReturnTool.sql*/
/**********************************************************************************************/
IF EXISTS (SELECT name 
	   FROM   sysobjects 
	   WHERE  name = 'ReturnTool' 
	   AND 	  type = 'P')
	DROP PROCEDURE ReturnTool
GO

CREATE PROCEDURE ReturnTool
@ToolTag varchar(100)
AS

DECLARE
@PersonId int


UPDATE TOOL SET
ToolInUse = 0,
PersonId = NULL,
RentDate = NULL
WHERE ToolTag = @ToolTag

GO
	
/**********************************************************************************************/
/*ReturnToolById.sql*/
/**********************************************************************************************/
IF EXISTS (SELECT name 
	   FROM   sysobjects 
	   WHERE  name = 'ReturnToolById' 
	   AND 	  type = 'P')
	DROP PROCEDURE ReturnToolById
GO

CREATE PROCEDURE ReturnToolById
@ToolId int
AS


UPDATE TOOL SET
ToolInUse = 0,
PersonId = NULL,
RentDate = NULL
WHERE ToolId = @ToolId

GO
	
/**********************************************************************************************/
/*SetToolStatus.sql*/
/**********************************************************************************************/
IF EXISTS (SELECT name 
	   FROM   sysobjects 
	   WHERE  name = 'SetToolStatus' 
	   AND 	  type = 'P')
	DROP PROCEDURE SetToolStatus
GO

CREATE PROCEDURE SetToolStatus
@PersonTag varchar(100),
@ToolTag varchar(100)
AS

DECLARE
@PersonId int,
@ToolInUse int

SELECT @PersonId = PersonId FROM PERSON WHERE PersonTag = @PersonTag

SELECT @ToolInUse = ToolInUse FROM TOOL WHERE ToolTag = @ToolTag

IF @ToolInUse=1
	BEGIN
		SET @ToolInUse=0
		UPDATE TOOL SET
		ToolInUse = @ToolInUse,
		PersonId = NULL,
		RentDate = NULL
		WHERE ToolTag = @ToolTag
	END
ELSE
	BEGIN
		SET @ToolInUse=1
		UPDATE TOOL SET
		ToolInUse = @ToolInUse,
		PersonId = @PersonId,
		RentDate = getdate()
		WHERE ToolTag = @ToolTag
	END

GO
	
/**********************************************************************************************/
/*UpdatePerson.sql*/
/**********************************************************************************************/
IF EXISTS (SELECT name 
	   FROM   sysobjects 
	   WHERE  name = 'UpdatePerson' 
	   AND 	  type = 'P')
	DROP PROCEDURE UpdatePerson
GO

CREATE PROCEDURE UpdatePerson
@PersonId int,
@PersonName varchar(100),
@PersonTag varchar(100),
@EMail varchar(1000)
AS

UPDATE PERSON SET
PersonName = @PersonName,
PersonTag = @PersonTag,
EMail = @EMail	 
WHERE PersonId = @PersonId

GO
	
/**********************************************************************************************/
/*UpdateTool.sql*/
/**********************************************************************************************/
IF EXISTS (SELECT name 
	   FROM   sysobjects 
	   WHERE  name = 'UpdateTool' 
	   AND 	  type = 'P')
	DROP PROCEDURE UpdateTool
GO

CREATE PROCEDURE UpdateTool
@ToolId int,
@ToolName varchar(100),
@ToolTag varchar(100),
@ToolDescription varchar(1000)
AS

UPDATE TOOL SET
ToolName = @ToolName,
ToolTag = @ToolTag,
ToolDescription = @ToolDescription	 
WHERE ToolId = @ToolId

GO

